@@ -26,18 +26,14 @@ public:
             lsofError(error);
         });
 
-        QObject::connect(&lsofProcess,
-                         QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
-                         job,
-                         [this](int exitCode, QProcess::ExitStatus exitStatus) {
-                             lsofFinished(exitCode, exitStatus);
-                         });
+        QObject::connect(&lsofProcess, qOverload<int, QProcess::ExitStatus>(&QProcess::finished), job, [this](int exitCode, QProcess::ExitStatus exitStatus) {
+            lsofFinished(exitCode, exitStatus);
+        });
     }
     void start()
     {
         if (!path.exists()) {
-            emitResult(static_cast<int>(KListOpenFilesJob::Error::DoesNotExist),
-                       QObject::tr("Path %1 doesn't exist").arg(path.path()));
+            emitResult(static_cast<int>(KListOpenFilesJob::Error::DoesNotExist), QObject::tr("Path %1 doesn't exist").arg(path.path()));
             return;
         }
         lsofProcess.start(QStringLiteral("lsof"), {QStringLiteral("-t"), QStringLiteral("+d"), path.path()});
@@ -46,11 +42,11 @@ public:
     {
         return processInfoList;
     }
+
 private:
     void lsofError(QProcess::ProcessError processError)
     {
-        emitResult(static_cast<int>(KListOpenFilesJob::Error::InternalError),
-                   QObject::tr("Failed to execute `lsof' error code %1").arg(processError));
+        emitResult(static_cast<int>(KListOpenFilesJob::Error::InternalError), QObject::tr("Failed to execute `lsof' error code %1").arg(processError));
     }
     void lsofFinished(int, QProcess::ExitStatus)
     {
@@ -58,7 +54,13 @@ private:
             return;
         }
         const QString out(QString::fromLocal8Bit(lsofProcess.readAll()));
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        const QVector<QStringView> pidList = QStringView(out).split(QRegularExpression(QStringLiteral("\\s+")), Qt::SkipEmptyParts);
+#else
         const QVector<QStringRef> pidList = out.splitRef(QRegularExpression(QStringLiteral("\\s+")), Qt::SkipEmptyParts);
+#endif
+
         for (const auto &pidStr : pidList) {
             qint64 pid = pidStr.toLongLong();
             if (!pid) {
@@ -68,7 +70,7 @@ private:
         }
         job->emitResult();
     }
-    void emitResult(int error, const QString& errorText)
+    void emitResult(int error, const QString &errorText)
     {
         if (hasEmittedResult) {
             return;
@@ -78,6 +80,7 @@ private:
         job->emitResult();
         hasEmittedResult = true;
     }
+
 private:
     KListOpenFilesJob *job;
     const QDir path;
@@ -86,7 +89,7 @@ private:
     KProcessList::KProcessInfoList processInfoList;
 };
 
-KListOpenFilesJob::KListOpenFilesJob(const QString& path)
+KListOpenFilesJob::KListOpenFilesJob(const QString &path)
     : d(new KListOpenFilesJobPrivate(this, path))
 {
 }
